/********************************************************************************
** Form generated from reading UI file 'dialog_topicselector.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOG_TOPICSELECTOR_H
#define UI_DIALOG_TOPICSELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogTopicSelector
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *label;
    QListWidget *list;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DialogTopicSelector)
    {
        if (DialogTopicSelector->objectName().isEmpty())
            DialogTopicSelector->setObjectName(QStringLiteral("DialogTopicSelector"));
        DialogTopicSelector->resize(218, 258);
        vboxLayout = new QVBoxLayout(DialogTopicSelector);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        label = new QLabel(DialogTopicSelector);
        label->setObjectName(QStringLiteral("label"));
        label->setAlignment(Qt::AlignCenter);

        vboxLayout->addWidget(label);

        list = new QListWidget(DialogTopicSelector);
        list->setObjectName(QStringLiteral("list"));

        vboxLayout->addWidget(list);

        buttonBox = new QDialogButtonBox(DialogTopicSelector);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::NoButton|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);


        retranslateUi(DialogTopicSelector);
        QObject::connect(buttonBox, SIGNAL(accepted()), DialogTopicSelector, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), DialogTopicSelector, SLOT(reject()));

        QMetaObject::connectSlotsByName(DialogTopicSelector);
    } // setupUi

    void retranslateUi(QDialog *DialogTopicSelector)
    {
        DialogTopicSelector->setWindowTitle(QApplication::translate("DialogTopicSelector", "Multiple topics", Q_NULLPTR));
        label->setText(QApplication::translate("DialogTopicSelector", "Please select the topic to open:", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class DialogTopicSelector: public Ui_DialogTopicSelector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOG_TOPICSELECTOR_H
