/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kchmviewer-7.7/src/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[49];
    char stringdata0[850];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 17), // "navSetBackEnabled"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 7), // "enabled"
QT_MOC_LITERAL(4, 38, 20), // "navSetForwardEnabled"
QT_MOC_LITERAL(5, 59, 18), // "onOpenPageInNewTab"
QT_MOC_LITERAL(6, 78, 28), // "onOpenPageInNewBackgroundTab"
QT_MOC_LITERAL(7, 107, 14), // "actionOpenFile"
QT_MOC_LITERAL(8, 122, 11), // "actionPrint"
QT_MOC_LITERAL(9, 134, 14), // "actionEditCopy"
QT_MOC_LITERAL(10, 149, 19), // "actionEditSelectAll"
QT_MOC_LITERAL(11, 169, 16), // "actionFindInPage"
QT_MOC_LITERAL(12, 186, 16), // "actionExtractCHM"
QT_MOC_LITERAL(13, 203, 20), // "actionChangeSettings"
QT_MOC_LITERAL(14, 224, 22), // "actionFontSizeIncrease"
QT_MOC_LITERAL(15, 247, 22), // "actionFontSizeDecrease"
QT_MOC_LITERAL(16, 270, 20), // "actionViewHTMLsource"
QT_MOC_LITERAL(17, 291, 22), // "actionToggleFullScreen"
QT_MOC_LITERAL(18, 314, 23), // "actionShowHideNavigator"
QT_MOC_LITERAL(19, 338, 26), // "navigatorVisibilityChanged"
QT_MOC_LITERAL(20, 365, 7), // "visible"
QT_MOC_LITERAL(21, 373, 25), // "actionLocateInContentsTab"
QT_MOC_LITERAL(22, 399, 18), // "actionEditToolbars"
QT_MOC_LITERAL(23, 418, 18), // "actionNavigateBack"
QT_MOC_LITERAL(24, 437, 21), // "actionNavigateForward"
QT_MOC_LITERAL(25, 459, 18), // "actionNavigateHome"
QT_MOC_LITERAL(26, 478, 14), // "actionAboutApp"
QT_MOC_LITERAL(27, 493, 13), // "actionAboutQt"
QT_MOC_LITERAL(28, 507, 24), // "actionSwitchToContentTab"
QT_MOC_LITERAL(29, 532, 22), // "actionSwitchToIndexTab"
QT_MOC_LITERAL(30, 555, 23), // "actionSwitchToSearchTab"
QT_MOC_LITERAL(31, 579, 25), // "actionSwitchToBookmarkTab"
QT_MOC_LITERAL(32, 605, 20), // "actionOpenRecentFile"
QT_MOC_LITERAL(33, 626, 4), // "file"
QT_MOC_LITERAL(34, 631, 21), // "actionEncodingChanged"
QT_MOC_LITERAL(35, 653, 8), // "QAction*"
QT_MOC_LITERAL(36, 662, 6), // "action"
QT_MOC_LITERAL(37, 669, 11), // "activateUrl"
QT_MOC_LITERAL(38, 681, 4), // "link"
QT_MOC_LITERAL(39, 686, 14), // "updateToolbars"
QT_MOC_LITERAL(40, 701, 13), // "updateActions"
QT_MOC_LITERAL(41, 715, 24), // "checkNewVersionAvailable"
QT_MOC_LITERAL(42, 740, 9), // "firstShow"
QT_MOC_LITERAL(43, 750, 16), // "newVerAvailError"
QT_MOC_LITERAL(44, 767, 15), // "newVerAvailable"
QT_MOC_LITERAL(45, 783, 17), // "NewVersionMetaMap"
QT_MOC_LITERAL(46, 801, 8), // "metadata"
QT_MOC_LITERAL(47, 810, 27), // "checkForSharedMemoryMessage"
QT_MOC_LITERAL(48, 838, 11) // "runAutoTest"

    },
    "MainWindow\0navSetBackEnabled\0\0enabled\0"
    "navSetForwardEnabled\0onOpenPageInNewTab\0"
    "onOpenPageInNewBackgroundTab\0"
    "actionOpenFile\0actionPrint\0actionEditCopy\0"
    "actionEditSelectAll\0actionFindInPage\0"
    "actionExtractCHM\0actionChangeSettings\0"
    "actionFontSizeIncrease\0actionFontSizeDecrease\0"
    "actionViewHTMLsource\0actionToggleFullScreen\0"
    "actionShowHideNavigator\0"
    "navigatorVisibilityChanged\0visible\0"
    "actionLocateInContentsTab\0actionEditToolbars\0"
    "actionNavigateBack\0actionNavigateForward\0"
    "actionNavigateHome\0actionAboutApp\0"
    "actionAboutQt\0actionSwitchToContentTab\0"
    "actionSwitchToIndexTab\0actionSwitchToSearchTab\0"
    "actionSwitchToBookmarkTab\0"
    "actionOpenRecentFile\0file\0"
    "actionEncodingChanged\0QAction*\0action\0"
    "activateUrl\0link\0updateToolbars\0"
    "updateActions\0checkNewVersionAvailable\0"
    "firstShow\0newVerAvailError\0newVerAvailable\0"
    "NewVersionMetaMap\0metadata\0"
    "checkForSharedMemoryMessage\0runAutoTest"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      39,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  209,    2, 0x0a /* Public */,
       4,    1,  212,    2, 0x0a /* Public */,
       5,    0,  215,    2, 0x0a /* Public */,
       6,    0,  216,    2, 0x0a /* Public */,
       7,    0,  217,    2, 0x0a /* Public */,
       8,    0,  218,    2, 0x0a /* Public */,
       9,    0,  219,    2, 0x0a /* Public */,
      10,    0,  220,    2, 0x0a /* Public */,
      11,    0,  221,    2, 0x0a /* Public */,
      12,    0,  222,    2, 0x0a /* Public */,
      13,    0,  223,    2, 0x0a /* Public */,
      14,    0,  224,    2, 0x0a /* Public */,
      15,    0,  225,    2, 0x0a /* Public */,
      16,    0,  226,    2, 0x0a /* Public */,
      17,    0,  227,    2, 0x0a /* Public */,
      18,    1,  228,    2, 0x0a /* Public */,
      19,    1,  231,    2, 0x0a /* Public */,
      21,    0,  234,    2, 0x0a /* Public */,
      22,    0,  235,    2, 0x0a /* Public */,
      23,    0,  236,    2, 0x0a /* Public */,
      24,    0,  237,    2, 0x0a /* Public */,
      25,    0,  238,    2, 0x0a /* Public */,
      26,    0,  239,    2, 0x0a /* Public */,
      27,    0,  240,    2, 0x0a /* Public */,
      28,    0,  241,    2, 0x0a /* Public */,
      29,    0,  242,    2, 0x0a /* Public */,
      30,    0,  243,    2, 0x0a /* Public */,
      31,    0,  244,    2, 0x0a /* Public */,
      32,    1,  245,    2, 0x0a /* Public */,
      34,    1,  248,    2, 0x0a /* Public */,
      37,    1,  251,    2, 0x0a /* Public */,
      39,    0,  254,    2, 0x0a /* Public */,
      40,    0,  255,    2, 0x0a /* Public */,
      41,    0,  256,    2, 0x0a /* Public */,
      42,    0,  257,    2, 0x09 /* Protected */,
      43,    1,  258,    2, 0x09 /* Protected */,
      44,    1,  261,    2, 0x09 /* Protected */,
      47,    0,  264,    2, 0x09 /* Protected */,
      48,    0,  265,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   33,
    QMetaType::Void, 0x80000000 | 35,   36,
    QMetaType::Void, QMetaType::QUrl,   38,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 45,   46,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MainWindow *_t = static_cast<MainWindow *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->navSetBackEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->navSetForwardEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->onOpenPageInNewTab(); break;
        case 3: _t->onOpenPageInNewBackgroundTab(); break;
        case 4: _t->actionOpenFile(); break;
        case 5: _t->actionPrint(); break;
        case 6: _t->actionEditCopy(); break;
        case 7: _t->actionEditSelectAll(); break;
        case 8: _t->actionFindInPage(); break;
        case 9: _t->actionExtractCHM(); break;
        case 10: _t->actionChangeSettings(); break;
        case 11: _t->actionFontSizeIncrease(); break;
        case 12: _t->actionFontSizeDecrease(); break;
        case 13: _t->actionViewHTMLsource(); break;
        case 14: _t->actionToggleFullScreen(); break;
        case 15: _t->actionShowHideNavigator((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->navigatorVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->actionLocateInContentsTab(); break;
        case 18: _t->actionEditToolbars(); break;
        case 19: _t->actionNavigateBack(); break;
        case 20: _t->actionNavigateForward(); break;
        case 21: _t->actionNavigateHome(); break;
        case 22: _t->actionAboutApp(); break;
        case 23: _t->actionAboutQt(); break;
        case 24: _t->actionSwitchToContentTab(); break;
        case 25: _t->actionSwitchToIndexTab(); break;
        case 26: _t->actionSwitchToSearchTab(); break;
        case 27: _t->actionSwitchToBookmarkTab(); break;
        case 28: _t->actionOpenRecentFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 29: _t->actionEncodingChanged((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 30: _t->activateUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 31: _t->updateToolbars(); break;
        case 32: _t->updateActions(); break;
        case 33: _t->checkNewVersionAvailable(); break;
        case 34: _t->firstShow(); break;
        case 35: _t->newVerAvailError((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 36: _t->newVerAvailable((*reinterpret_cast< NewVersionMetaMap(*)>(_a[1]))); break;
        case 37: _t->checkForSharedMemoryMessage(); break;
        case 38: _t->runAutoTest(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NewVersionMetaMap >(); break;
            }
            break;
        }
    }
}

const QMetaObject MainWindow::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_MainWindow.data,
      qt_meta_data_MainWindow,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::MainWindow"))
        return static_cast< Ui::MainWindow*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
