/********************************************************************************
** Form generated from reading UI file 'tab_contents.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAB_CONTENTS_H
#define UI_TAB_CONTENTS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TabContents
{
public:
    QVBoxLayout *vboxLayout;
    QTreeWidget *tree;

    void setupUi(QWidget *TabContents)
    {
        if (TabContents->objectName().isEmpty())
            TabContents->setObjectName(QStringLiteral("TabContents"));
        TabContents->resize(257, 424);
        vboxLayout = new QVBoxLayout(TabContents);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        tree = new QTreeWidget(TabContents);
        tree->setObjectName(QStringLiteral("tree"));

        vboxLayout->addWidget(tree);


        retranslateUi(TabContents);

        QMetaObject::connectSlotsByName(TabContents);
    } // setupUi

    void retranslateUi(QWidget *TabContents)
    {
        TabContents->setWindowTitle(QApplication::translate("TabContents", "Form1", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class TabContents: public Ui_TabContents {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TAB_CONTENTS_H
