/********************************************************************************
** Form generated from reading UI file 'tab_index.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAB_INDEX_H
#define UI_TAB_INDEX_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TabIndex
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QLineEdit *text;
    QTreeWidget *tree;

    void setupUi(QWidget *TabIndex)
    {
        if (TabIndex->objectName().isEmpty())
            TabIndex->setObjectName(QStringLiteral("TabIndex"));
        TabIndex->resize(173, 382);
        verticalLayout = new QVBoxLayout(TabIndex);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(TabIndex);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        text = new QLineEdit(TabIndex);
        text->setObjectName(QStringLiteral("text"));

        horizontalLayout->addWidget(text);


        verticalLayout->addLayout(horizontalLayout);

        tree = new QTreeWidget(TabIndex);
        tree->setObjectName(QStringLiteral("tree"));
        tree->setIndentation(10);
        tree->setRootIsDecorated(false);
        tree->setAllColumnsShowFocus(true);
        tree->setColumnCount(1);

        verticalLayout->addWidget(tree);

#ifndef QT_NO_SHORTCUT
        label->setBuddy(text);
#endif // QT_NO_SHORTCUT

        retranslateUi(TabIndex);

        QMetaObject::connectSlotsByName(TabIndex);
    } // setupUi

    void retranslateUi(QWidget *TabIndex)
    {
        TabIndex->setWindowTitle(QApplication::translate("TabIndex", "Form1", Q_NULLPTR));
        label->setText(QApplication::translate("TabIndex", "F&ind:", Q_NULLPTR));
        QTreeWidgetItem *___qtreewidgetitem = tree->headerItem();
        ___qtreewidgetitem->setText(0, QApplication::translate("TabIndex", "1", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class TabIndex: public Ui_TabIndex {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TAB_INDEX_H
