/********************************************************************************
** Form generated from reading UI file 'tab_search.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAB_SEARCH_H
#define UI_TAB_SEARCH_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TabSearch
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QLabel *lblHelp;
    QHBoxLayout *hboxLayout1;
    QComboBox *searchBox;
    QPushButton *btnGo;
    QTreeWidget *tree;

    void setupUi(QWidget *TabSearch)
    {
        if (TabSearch->objectName().isEmpty())
            TabSearch->setObjectName(QStringLiteral("TabSearch"));
        TabSearch->resize(210, 409);
        vboxLayout = new QVBoxLayout(TabSearch);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        label = new QLabel(TabSearch);
        label->setObjectName(QStringLiteral("label"));

        hboxLayout->addWidget(label);

        lblHelp = new QLabel(TabSearch);
        lblHelp->setObjectName(QStringLiteral("lblHelp"));
        QSizePolicy sizePolicy(static_cast<QSizePolicy::Policy>(0), static_cast<QSizePolicy::Policy>(0));
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lblHelp->sizePolicy().hasHeightForWidth());
        lblHelp->setSizePolicy(sizePolicy);
        lblHelp->setTextFormat(Qt::RichText);

        hboxLayout->addWidget(lblHelp);


        vboxLayout->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        searchBox = new QComboBox(TabSearch);
        searchBox->setObjectName(QStringLiteral("searchBox"));
        QSizePolicy sizePolicy1(static_cast<QSizePolicy::Policy>(7), static_cast<QSizePolicy::Policy>(0));
        sizePolicy1.setHorizontalStretch(2);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(searchBox->sizePolicy().hasHeightForWidth());
        searchBox->setSizePolicy(sizePolicy1);
        searchBox->setEditable(true);
        searchBox->setMaxCount(10);

        hboxLayout1->addWidget(searchBox);

        btnGo = new QPushButton(TabSearch);
        btnGo->setObjectName(QStringLiteral("btnGo"));

        hboxLayout1->addWidget(btnGo);


        vboxLayout->addLayout(hboxLayout1);

        tree = new QTreeWidget(TabSearch);
        tree->setObjectName(QStringLiteral("tree"));
        tree->setRootIsDecorated(false);
        tree->setItemsExpandable(false);
        tree->setSortingEnabled(false);
        tree->setAllColumnsShowFocus(true);
        tree->setColumnCount(2);

        vboxLayout->addWidget(tree);


        retranslateUi(TabSearch);

        QMetaObject::connectSlotsByName(TabSearch);
    } // setupUi

    void retranslateUi(QWidget *TabSearch)
    {
        TabSearch->setWindowTitle(QApplication::translate("TabSearch", "Form1", Q_NULLPTR));
        label->setText(QApplication::translate("TabSearch", "Type in word(s) to search for:", Q_NULLPTR));
        lblHelp->setText(QApplication::translate("TabSearch", "<a href=\"help\">Help</a>", Q_NULLPTR));
        btnGo->setText(QApplication::translate("TabSearch", "&Go", Q_NULLPTR));
        QTreeWidgetItem *___qtreewidgetitem = tree->headerItem();
        ___qtreewidgetitem->setText(1, QApplication::translate("TabSearch", "Location", Q_NULLPTR));
        ___qtreewidgetitem->setText(0, QApplication::translate("TabSearch", "Title", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class TabSearch: public Ui_TabSearch {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TAB_SEARCH_H
