/********************************************************************************
** Form generated from reading UI file 'navigatorpanel.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NAVIGATORPANEL_H
#define UI_NAVIGATORPANEL_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QDockWidget>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_NavigatorPanel
{
public:
    QWidget *dockWidgetContents;
    QVBoxLayout *verticalLayout;
    QTabWidget *m_tabWidget;
    QWidget *tab;

    void setupUi(QDockWidget *NavigatorPanel)
    {
        if (NavigatorPanel->objectName().isEmpty())
            NavigatorPanel->setObjectName(QStringLiteral("NavigatorPanel"));
        NavigatorPanel->resize(400, 300);
        NavigatorPanel->setAllowedAreas(Qt::LeftDockWidgetArea|Qt::RightDockWidgetArea);
        dockWidgetContents = new QWidget();
        dockWidgetContents->setObjectName(QStringLiteral("dockWidgetContents"));
        verticalLayout = new QVBoxLayout(dockWidgetContents);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        m_tabWidget = new QTabWidget(dockWidgetContents);
        m_tabWidget->setObjectName(QStringLiteral("m_tabWidget"));
        tab = new QWidget();
        tab->setObjectName(QStringLiteral("tab"));
        m_tabWidget->addTab(tab, QString());

        verticalLayout->addWidget(m_tabWidget);

        NavigatorPanel->setWidget(dockWidgetContents);

        retranslateUi(NavigatorPanel);

        m_tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(NavigatorPanel);
    } // setupUi

    void retranslateUi(QDockWidget *NavigatorPanel)
    {
        NavigatorPanel->setWindowTitle(QApplication::translate("NavigatorPanel", "Navigator panel", Q_NULLPTR));
        m_tabWidget->setTabText(m_tabWidget->indexOf(tab), QApplication::translate("NavigatorPanel", "Tab 1", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class NavigatorPanel: public Ui_NavigatorPanel {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_NAVIGATORPANEL_H
