/****************************************************************************
** Meta object code from reading C++ file 'viewwindowmgr.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kchmviewer-7.7/src/viewwindowmgr.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewwindowmgr.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ViewWindowMgr_t {
    QByteArrayData data[20];
    char stringdata0[258];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ViewWindowMgr_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ViewWindowMgr_t qt_meta_stringdata_ViewWindowMgr = {
    {
QT_MOC_LITERAL(0, 0, 13), // "ViewWindowMgr"
QT_MOC_LITERAL(1, 14, 20), // "onCloseCurrentWindow"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 13), // "onCloseWindow"
QT_MOC_LITERAL(4, 50, 3), // "num"
QT_MOC_LITERAL(5, 54, 14), // "onActivateFind"
QT_MOC_LITERAL(6, 69, 10), // "onFindNext"
QT_MOC_LITERAL(7, 80, 14), // "onFindPrevious"
QT_MOC_LITERAL(8, 95, 22), // "onWindowContentChanged"
QT_MOC_LITERAL(9, 118, 11), // "ViewWindow*"
QT_MOC_LITERAL(10, 130, 6), // "window"
QT_MOC_LITERAL(11, 137, 18), // "copyUrlToClipboard"
QT_MOC_LITERAL(12, 156, 10), // "openNewTab"
QT_MOC_LITERAL(13, 167, 12), // "onTabChanged"
QT_MOC_LITERAL(14, 180, 11), // "newtabIndex"
QT_MOC_LITERAL(15, 192, 18), // "updateCloseButtons"
QT_MOC_LITERAL(16, 211, 14), // "activateWindow"
QT_MOC_LITERAL(17, 226, 11), // "closeSearch"
QT_MOC_LITERAL(18, 238, 14), // "editTextEdited"
QT_MOC_LITERAL(19, 253, 4) // "text"

    },
    "ViewWindowMgr\0onCloseCurrentWindow\0\0"
    "onCloseWindow\0num\0onActivateFind\0"
    "onFindNext\0onFindPrevious\0"
    "onWindowContentChanged\0ViewWindow*\0"
    "window\0copyUrlToClipboard\0openNewTab\0"
    "onTabChanged\0newtabIndex\0updateCloseButtons\0"
    "activateWindow\0closeSearch\0editTextEdited\0"
    "text"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ViewWindowMgr[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x0a /* Public */,
       3,    1,   80,    2, 0x0a /* Public */,
       5,    0,   83,    2, 0x0a /* Public */,
       6,    0,   84,    2, 0x0a /* Public */,
       7,    0,   85,    2, 0x0a /* Public */,
       8,    1,   86,    2, 0x0a /* Public */,
      11,    0,   89,    2, 0x0a /* Public */,
      12,    0,   90,    2, 0x09 /* Protected */,
      13,    1,   91,    2, 0x09 /* Protected */,
      15,    0,   94,    2, 0x09 /* Protected */,
      16,    0,   95,    2, 0x09 /* Protected */,
      17,    0,   96,    2, 0x09 /* Protected */,
      18,    1,   97,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   19,

       0        // eod
};

void ViewWindowMgr::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ViewWindowMgr *_t = static_cast<ViewWindowMgr *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onCloseCurrentWindow(); break;
        case 1: _t->onCloseWindow((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->onActivateFind(); break;
        case 3: _t->onFindNext(); break;
        case 4: _t->onFindPrevious(); break;
        case 5: _t->onWindowContentChanged((*reinterpret_cast< ViewWindow*(*)>(_a[1]))); break;
        case 6: _t->copyUrlToClipboard(); break;
        case 7: _t->openNewTab(); break;
        case 8: _t->onTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->updateCloseButtons(); break;
        case 10: _t->activateWindow(); break;
        case 11: _t->closeSearch(); break;
        case 12: _t->editTextEdited((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject ViewWindowMgr::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ViewWindowMgr.data,
      qt_meta_data_ViewWindowMgr,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ViewWindowMgr::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewWindowMgr::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ViewWindowMgr.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TabbedBrowser"))
        return static_cast< Ui::TabbedBrowser*>(this);
    return QWidget::qt_metacast(_clname);
}

int ViewWindowMgr::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
