/********************************************************************************
** Form generated from reading UI file 'tab_bookmarks.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TAB_BOOKMARKS_H
#define UI_TAB_BOOKMARKS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TabBookmarks
{
public:
    QVBoxLayout *vboxLayout;
    QListWidget *list;
    QHBoxLayout *hboxLayout;
    QPushButton *btnAdd;
    QPushButton *btnEdit;
    QPushButton *btnDel;

    void setupUi(QWidget *TabBookmarks)
    {
        if (TabBookmarks->objectName().isEmpty())
            TabBookmarks->setObjectName(QStringLiteral("TabBookmarks"));
        TabBookmarks->resize(257, 296);
        vboxLayout = new QVBoxLayout(TabBookmarks);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        list = new QListWidget(TabBookmarks);
        list->setObjectName(QStringLiteral("list"));

        vboxLayout->addWidget(list);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        btnAdd = new QPushButton(TabBookmarks);
        btnAdd->setObjectName(QStringLiteral("btnAdd"));

        hboxLayout->addWidget(btnAdd);

        btnEdit = new QPushButton(TabBookmarks);
        btnEdit->setObjectName(QStringLiteral("btnEdit"));

        hboxLayout->addWidget(btnEdit);

        btnDel = new QPushButton(TabBookmarks);
        btnDel->setObjectName(QStringLiteral("btnDel"));

        hboxLayout->addWidget(btnDel);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(TabBookmarks);

        QMetaObject::connectSlotsByName(TabBookmarks);
    } // setupUi

    void retranslateUi(QWidget *TabBookmarks)
    {
        TabBookmarks->setWindowTitle(QString());
        btnAdd->setText(QApplication::translate("TabBookmarks", "&Add", Q_NULLPTR));
        btnEdit->setText(QApplication::translate("TabBookmarks", "Edi&t", Q_NULLPTR));
        btnDel->setText(QApplication::translate("TabBookmarks", "&Del", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class TabBookmarks: public Ui_TabBookmarks {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TAB_BOOKMARKS_H
