/********************************************************************************
** Form generated from reading UI file 'toolbareditor.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TOOLBAREDITOR_H
#define UI_TOOLBAREDITOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_ToolbarEditor
{
public:
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupEditToolbars;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *boxToolbars;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QListView *listAvailable;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_4;
    QListView *listActions;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ToolbarEditor)
    {
        if (ToolbarEditor->objectName().isEmpty())
            ToolbarEditor->setObjectName(QStringLiteral("ToolbarEditor"));
        ToolbarEditor->resize(497, 386);
        verticalLayout_3 = new QVBoxLayout(ToolbarEditor);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        groupEditToolbars = new QGroupBox(ToolbarEditor);
        groupEditToolbars->setObjectName(QStringLiteral("groupEditToolbars"));
        horizontalLayout = new QHBoxLayout(groupEditToolbars);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(groupEditToolbars);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        boxToolbars = new QComboBox(groupEditToolbars);
        boxToolbars->setObjectName(QStringLiteral("boxToolbars"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(boxToolbars->sizePolicy().hasHeightForWidth());
        boxToolbars->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(boxToolbars);


        verticalLayout_3->addWidget(groupEditToolbars);

        label_2 = new QLabel(ToolbarEditor);
        label_2->setObjectName(QStringLiteral("label_2"));
        label_2->setAlignment(Qt::AlignCenter);

        verticalLayout_3->addWidget(label_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        groupBox = new QGroupBox(ToolbarEditor);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(2);
        sizePolicy1.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy1);
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        listAvailable = new QListView(groupBox);
        listAvailable->setObjectName(QStringLiteral("listAvailable"));
        listAvailable->setDragEnabled(true);
        listAvailable->setDragDropMode(QAbstractItemView::DragDrop);

        verticalLayout_2->addWidget(listAvailable);


        horizontalLayout_2->addWidget(groupBox);

        groupBox_2 = new QGroupBox(ToolbarEditor);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        sizePolicy1.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy1);
        verticalLayout_4 = new QVBoxLayout(groupBox_2);
        verticalLayout_4->setObjectName(QStringLiteral("verticalLayout_4"));
        listActions = new QListView(groupBox_2);
        listActions->setObjectName(QStringLiteral("listActions"));
        listActions->setDragEnabled(true);
        listActions->setDragDropMode(QAbstractItemView::DragDrop);

        verticalLayout_4->addWidget(listActions);


        horizontalLayout_2->addWidget(groupBox_2);


        verticalLayout_3->addLayout(horizontalLayout_2);

        buttonBox = new QDialogButtonBox(ToolbarEditor);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_3->addWidget(buttonBox);


        retranslateUi(ToolbarEditor);
        QObject::connect(buttonBox, SIGNAL(accepted()), ToolbarEditor, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), ToolbarEditor, SLOT(reject()));

        QMetaObject::connectSlotsByName(ToolbarEditor);
    } // setupUi

    void retranslateUi(QDialog *ToolbarEditor)
    {
        ToolbarEditor->setWindowTitle(QApplication::translate("ToolbarEditor", "Dialog", Q_NULLPTR));
        groupEditToolbars->setTitle(QApplication::translate("ToolbarEditor", "Select a toolbar", Q_NULLPTR));
        label->setText(QApplication::translate("ToolbarEditor", "Editing the toolbar ", Q_NULLPTR));
        label_2->setText(QApplication::translate("ToolbarEditor", "Drag the actions to the toolbar list to add them to the toolbar. \n"
"Drag them from toolbar list to remove them from the toolbar.", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("ToolbarEditor", "Available actions", Q_NULLPTR));
        groupBox_2->setTitle(QApplication::translate("ToolbarEditor", "Toolbar actions", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class ToolbarEditor: public Ui_ToolbarEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TOOLBAREDITOR_H
