/********************************************************************************
** Form generated from reading UI file 'dialog_setup.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOG_SETUP_H
#define UI_DIALOG_SETUP_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_DialogSetup
{
public:
    QVBoxLayout *vboxLayout;
    QTabWidget *tabWidget;
    QWidget *Widget8;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QGroupBox *buttonGroup1;
    QVBoxLayout *vboxLayout2;
    QRadioButton *rbStartWithNothing;
    QRadioButton *m_radioOnBeginOpenDialog;
    QRadioButton *m_radioOnBeginOpenLast;
    QGroupBox *buttonGroup2;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel1;
    QSpinBox *m_historySize;
    QLabel *textLabel2;
    QCheckBox *m_rememberHistoryInfo;
    QGroupBox *groupBox1;
    QHBoxLayout *hboxLayout2;
    QGroupBox *buttonGroup4;
    QVBoxLayout *vboxLayout4;
    QRadioButton *m_radioExtLinkOpenAlways;
    QRadioButton *m_radioExtLinkAsk;
    QRadioButton *m_radioExtLinkOpenNever;
    QGroupBox *buttonGroup5;
    QVBoxLayout *vboxLayout5;
    QRadioButton *m_radioNewChmOpenAlways;
    QRadioButton *m_radioNewChmAsk;
    QRadioButton *m_radioNewChmOpenNever;
    QSpacerItem *spacerItem;
    QWidget *Widget9;
    QVBoxLayout *vboxLayout6;
    QGroupBox *m_groupKDEsettings;
    QVBoxLayout *verticalLayout;
    QCheckBox *m_enableImages;
    QCheckBox *m_enablePlugins;
    QCheckBox *m_enableJava;
    QCheckBox *m_enableJS;
    QCheckBox *m_enableOfflineStorage;
    QCheckBox *m_enableLocalStorage;
    QCheckBox *m_highlightSearchResults;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *m_openAllTOCEntries;
    QCheckBox *boxUseSingleClick;
    QSpacerItem *spacerItem1;
    QWidget *TabPage;
    QVBoxLayout *vboxLayout7;
    QGroupBox *buttonGroup7;
    QVBoxLayout *vboxLayout8;
    QRadioButton *m_advViewSourceInternal;
    QRadioButton *m_advViewSourceExternal;
    QHBoxLayout *hboxLayout3;
    QLabel *textLabel1_3;
    QLineEdit *m_advExternalProgramName;
    QPushButton *btnBrowse;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout9;
    QCheckBox *boxLayoutDirectionRL;
    QCheckBox *boxAutodetectEncoding;
    QCheckBox *cbCheckForUpdates;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout;
    QRadioButton *rbToolbarSmall;
    QRadioButton *rbToolbarLarge;
    QRadioButton *rbToolbarLargeText;
    QRadioButton *rbToolbarText;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *spacerItem2;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *DialogSetup)
    {
        if (DialogSetup->objectName().isEmpty())
            DialogSetup->setObjectName(QStringLiteral("DialogSetup"));
        DialogSetup->resize(630, 441);
        QSizePolicy sizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DialogSetup->sizePolicy().hasHeightForWidth());
        DialogSetup->setSizePolicy(sizePolicy);
        DialogSetup->setSizeGripEnabled(false);
        DialogSetup->setModal(true);
        vboxLayout = new QVBoxLayout(DialogSetup);
        vboxLayout->setSpacing(6);
        vboxLayout->setContentsMargins(9, 9, 9, 9);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        tabWidget = new QTabWidget(DialogSetup);
        tabWidget->setObjectName(QStringLiteral("tabWidget"));
        Widget8 = new QWidget();
        Widget8->setObjectName(QStringLiteral("Widget8"));
        vboxLayout1 = new QVBoxLayout(Widget8);
        vboxLayout1->setSpacing(6);
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
        vboxLayout1->setObjectName(QStringLiteral("vboxLayout1"));
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(6);
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        buttonGroup1 = new QGroupBox(Widget8);
        buttonGroup1->setObjectName(QStringLiteral("buttonGroup1"));
        vboxLayout2 = new QVBoxLayout(buttonGroup1);
        vboxLayout2->setSpacing(6);
        vboxLayout2->setContentsMargins(9, 9, 9, 9);
        vboxLayout2->setObjectName(QStringLiteral("vboxLayout2"));
        rbStartWithNothing = new QRadioButton(buttonGroup1);
        rbStartWithNothing->setObjectName(QStringLiteral("rbStartWithNothing"));

        vboxLayout2->addWidget(rbStartWithNothing);

        m_radioOnBeginOpenDialog = new QRadioButton(buttonGroup1);
        m_radioOnBeginOpenDialog->setObjectName(QStringLiteral("m_radioOnBeginOpenDialog"));

        vboxLayout2->addWidget(m_radioOnBeginOpenDialog);

        m_radioOnBeginOpenLast = new QRadioButton(buttonGroup1);
        m_radioOnBeginOpenLast->setObjectName(QStringLiteral("m_radioOnBeginOpenLast"));

        vboxLayout2->addWidget(m_radioOnBeginOpenLast);


        hboxLayout->addWidget(buttonGroup1);

        buttonGroup2 = new QGroupBox(Widget8);
        buttonGroup2->setObjectName(QStringLiteral("buttonGroup2"));
        vboxLayout3 = new QVBoxLayout(buttonGroup2);
        vboxLayout3->setSpacing(6);
        vboxLayout3->setContentsMargins(9, 9, 9, 9);
        vboxLayout3->setObjectName(QStringLiteral("vboxLayout3"));
        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setSpacing(6);
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        textLabel1 = new QLabel(buttonGroup2);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setWordWrap(false);

        hboxLayout1->addWidget(textLabel1);

        m_historySize = new QSpinBox(buttonGroup2);
        m_historySize->setObjectName(QStringLiteral("m_historySize"));
        m_historySize->setValue(10);

        hboxLayout1->addWidget(m_historySize);

        textLabel2 = new QLabel(buttonGroup2);
        textLabel2->setObjectName(QStringLiteral("textLabel2"));
        textLabel2->setWordWrap(false);

        hboxLayout1->addWidget(textLabel2);


        vboxLayout3->addLayout(hboxLayout1);

        m_rememberHistoryInfo = new QCheckBox(buttonGroup2);
        m_rememberHistoryInfo->setObjectName(QStringLiteral("m_rememberHistoryInfo"));

        vboxLayout3->addWidget(m_rememberHistoryInfo);


        hboxLayout->addWidget(buttonGroup2);


        vboxLayout1->addLayout(hboxLayout);

        groupBox1 = new QGroupBox(Widget8);
        groupBox1->setObjectName(QStringLiteral("groupBox1"));
        hboxLayout2 = new QHBoxLayout(groupBox1);
        hboxLayout2->setSpacing(6);
        hboxLayout2->setContentsMargins(9, 9, 9, 9);
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        buttonGroup4 = new QGroupBox(groupBox1);
        buttonGroup4->setObjectName(QStringLiteral("buttonGroup4"));
        vboxLayout4 = new QVBoxLayout(buttonGroup4);
        vboxLayout4->setSpacing(6);
        vboxLayout4->setContentsMargins(9, 9, 9, 9);
        vboxLayout4->setObjectName(QStringLiteral("vboxLayout4"));
        m_radioExtLinkOpenAlways = new QRadioButton(buttonGroup4);
        m_radioExtLinkOpenAlways->setObjectName(QStringLiteral("m_radioExtLinkOpenAlways"));

        vboxLayout4->addWidget(m_radioExtLinkOpenAlways);

        m_radioExtLinkAsk = new QRadioButton(buttonGroup4);
        m_radioExtLinkAsk->setObjectName(QStringLiteral("m_radioExtLinkAsk"));

        vboxLayout4->addWidget(m_radioExtLinkAsk);

        m_radioExtLinkOpenNever = new QRadioButton(buttonGroup4);
        m_radioExtLinkOpenNever->setObjectName(QStringLiteral("m_radioExtLinkOpenNever"));

        vboxLayout4->addWidget(m_radioExtLinkOpenNever);


        hboxLayout2->addWidget(buttonGroup4);

        buttonGroup5 = new QGroupBox(groupBox1);
        buttonGroup5->setObjectName(QStringLiteral("buttonGroup5"));
        vboxLayout5 = new QVBoxLayout(buttonGroup5);
        vboxLayout5->setSpacing(6);
        vboxLayout5->setContentsMargins(9, 9, 9, 9);
        vboxLayout5->setObjectName(QStringLiteral("vboxLayout5"));
        m_radioNewChmOpenAlways = new QRadioButton(buttonGroup5);
        m_radioNewChmOpenAlways->setObjectName(QStringLiteral("m_radioNewChmOpenAlways"));

        vboxLayout5->addWidget(m_radioNewChmOpenAlways);

        m_radioNewChmAsk = new QRadioButton(buttonGroup5);
        m_radioNewChmAsk->setObjectName(QStringLiteral("m_radioNewChmAsk"));

        vboxLayout5->addWidget(m_radioNewChmAsk);

        m_radioNewChmOpenNever = new QRadioButton(buttonGroup5);
        m_radioNewChmOpenNever->setObjectName(QStringLiteral("m_radioNewChmOpenNever"));

        vboxLayout5->addWidget(m_radioNewChmOpenNever);


        hboxLayout2->addWidget(buttonGroup5);


        vboxLayout1->addWidget(groupBox1);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout1->addItem(spacerItem);

        tabWidget->addTab(Widget8, QString());
        Widget9 = new QWidget();
        Widget9->setObjectName(QStringLiteral("Widget9"));
        vboxLayout6 = new QVBoxLayout(Widget9);
        vboxLayout6->setSpacing(6);
        vboxLayout6->setContentsMargins(9, 9, 9, 9);
        vboxLayout6->setObjectName(QStringLiteral("vboxLayout6"));
        m_groupKDEsettings = new QGroupBox(Widget9);
        m_groupKDEsettings->setObjectName(QStringLiteral("m_groupKDEsettings"));
        verticalLayout = new QVBoxLayout(m_groupKDEsettings);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        m_enableImages = new QCheckBox(m_groupKDEsettings);
        m_enableImages->setObjectName(QStringLiteral("m_enableImages"));

        verticalLayout->addWidget(m_enableImages);

        m_enablePlugins = new QCheckBox(m_groupKDEsettings);
        m_enablePlugins->setObjectName(QStringLiteral("m_enablePlugins"));

        verticalLayout->addWidget(m_enablePlugins);

        m_enableJava = new QCheckBox(m_groupKDEsettings);
        m_enableJava->setObjectName(QStringLiteral("m_enableJava"));

        verticalLayout->addWidget(m_enableJava);

        m_enableJS = new QCheckBox(m_groupKDEsettings);
        m_enableJS->setObjectName(QStringLiteral("m_enableJS"));

        verticalLayout->addWidget(m_enableJS);

        m_enableOfflineStorage = new QCheckBox(m_groupKDEsettings);
        m_enableOfflineStorage->setObjectName(QStringLiteral("m_enableOfflineStorage"));

        verticalLayout->addWidget(m_enableOfflineStorage);

        m_enableLocalStorage = new QCheckBox(m_groupKDEsettings);
        m_enableLocalStorage->setObjectName(QStringLiteral("m_enableLocalStorage"));

        verticalLayout->addWidget(m_enableLocalStorage);

        m_highlightSearchResults = new QCheckBox(m_groupKDEsettings);
        m_highlightSearchResults->setObjectName(QStringLiteral("m_highlightSearchResults"));

        verticalLayout->addWidget(m_highlightSearchResults);


        vboxLayout6->addWidget(m_groupKDEsettings);

        groupBox_3 = new QGroupBox(Widget9);
        groupBox_3->setObjectName(QStringLiteral("groupBox_3"));
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        m_openAllTOCEntries = new QCheckBox(groupBox_3);
        m_openAllTOCEntries->setObjectName(QStringLiteral("m_openAllTOCEntries"));

        verticalLayout_2->addWidget(m_openAllTOCEntries);

        boxUseSingleClick = new QCheckBox(groupBox_3);
        boxUseSingleClick->setObjectName(QStringLiteral("boxUseSingleClick"));

        verticalLayout_2->addWidget(boxUseSingleClick);


        vboxLayout6->addWidget(groupBox_3);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout6->addItem(spacerItem1);

        tabWidget->addTab(Widget9, QString());
        TabPage = new QWidget();
        TabPage->setObjectName(QStringLiteral("TabPage"));
        vboxLayout7 = new QVBoxLayout(TabPage);
        vboxLayout7->setSpacing(6);
        vboxLayout7->setContentsMargins(11, 11, 11, 11);
        vboxLayout7->setObjectName(QStringLiteral("vboxLayout7"));
        buttonGroup7 = new QGroupBox(TabPage);
        buttonGroup7->setObjectName(QStringLiteral("buttonGroup7"));
        vboxLayout8 = new QVBoxLayout(buttonGroup7);
        vboxLayout8->setSpacing(6);
        vboxLayout8->setContentsMargins(9, 9, 9, 9);
        vboxLayout8->setObjectName(QStringLiteral("vboxLayout8"));
        m_advViewSourceInternal = new QRadioButton(buttonGroup7);
        m_advViewSourceInternal->setObjectName(QStringLiteral("m_advViewSourceInternal"));

        vboxLayout8->addWidget(m_advViewSourceInternal);

        m_advViewSourceExternal = new QRadioButton(buttonGroup7);
        m_advViewSourceExternal->setObjectName(QStringLiteral("m_advViewSourceExternal"));

        vboxLayout8->addWidget(m_advViewSourceExternal);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setSpacing(6);
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName(QStringLiteral("hboxLayout3"));
        textLabel1_3 = new QLabel(buttonGroup7);
        textLabel1_3->setObjectName(QStringLiteral("textLabel1_3"));
        textLabel1_3->setWordWrap(false);

        hboxLayout3->addWidget(textLabel1_3);

        m_advExternalProgramName = new QLineEdit(buttonGroup7);
        m_advExternalProgramName->setObjectName(QStringLiteral("m_advExternalProgramName"));

        hboxLayout3->addWidget(m_advExternalProgramName);

        btnBrowse = new QPushButton(buttonGroup7);
        btnBrowse->setObjectName(QStringLiteral("btnBrowse"));

        hboxLayout3->addWidget(btnBrowse);


        vboxLayout8->addLayout(hboxLayout3);


        vboxLayout7->addWidget(buttonGroup7);

        groupBox = new QGroupBox(TabPage);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        vboxLayout9 = new QVBoxLayout(groupBox);
        vboxLayout9->setSpacing(6);
        vboxLayout9->setContentsMargins(11, 11, 11, 11);
        vboxLayout9->setObjectName(QStringLiteral("vboxLayout9"));
        boxLayoutDirectionRL = new QCheckBox(groupBox);
        boxLayoutDirectionRL->setObjectName(QStringLiteral("boxLayoutDirectionRL"));

        vboxLayout9->addWidget(boxLayoutDirectionRL);

        boxAutodetectEncoding = new QCheckBox(groupBox);
        boxAutodetectEncoding->setObjectName(QStringLiteral("boxAutodetectEncoding"));

        vboxLayout9->addWidget(boxAutodetectEncoding);

        cbCheckForUpdates = new QCheckBox(groupBox);
        cbCheckForUpdates->setObjectName(QStringLiteral("cbCheckForUpdates"));

        vboxLayout9->addWidget(cbCheckForUpdates);


        vboxLayout7->addWidget(groupBox);

        groupBox_2 = new QGroupBox(TabPage);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        horizontalLayout = new QHBoxLayout(groupBox_2);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(11, 11, 11, 11);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        rbToolbarSmall = new QRadioButton(groupBox_2);
        rbToolbarSmall->setObjectName(QStringLiteral("rbToolbarSmall"));

        horizontalLayout->addWidget(rbToolbarSmall);

        rbToolbarLarge = new QRadioButton(groupBox_2);
        rbToolbarLarge->setObjectName(QStringLiteral("rbToolbarLarge"));

        horizontalLayout->addWidget(rbToolbarLarge);

        rbToolbarLargeText = new QRadioButton(groupBox_2);
        rbToolbarLargeText->setObjectName(QStringLiteral("rbToolbarLargeText"));

        horizontalLayout->addWidget(rbToolbarLargeText);

        rbToolbarText = new QRadioButton(groupBox_2);
        rbToolbarText->setObjectName(QStringLiteral("rbToolbarText"));

        horizontalLayout->addWidget(rbToolbarText);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        vboxLayout7->addWidget(groupBox_2);

        spacerItem2 = new QSpacerItem(567, 21, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout7->addItem(spacerItem2);

        tabWidget->addTab(TabPage, QString());

        vboxLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(DialogSetup);
        buttonBox->setObjectName(QStringLiteral("buttonBox"));
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

        QWidget::setTabOrder(m_radioOnBeginOpenDialog, m_radioOnBeginOpenLast);
        QWidget::setTabOrder(m_radioOnBeginOpenLast, m_historySize);
        QWidget::setTabOrder(m_historySize, m_rememberHistoryInfo);
        QWidget::setTabOrder(m_rememberHistoryInfo, m_radioExtLinkOpenAlways);
        QWidget::setTabOrder(m_radioExtLinkOpenAlways, m_radioExtLinkAsk);
        QWidget::setTabOrder(m_radioExtLinkAsk, m_radioExtLinkOpenNever);
        QWidget::setTabOrder(m_radioExtLinkOpenNever, m_radioNewChmOpenAlways);
        QWidget::setTabOrder(m_radioNewChmOpenAlways, m_radioNewChmAsk);
        QWidget::setTabOrder(m_radioNewChmAsk, m_radioNewChmOpenNever);
        QWidget::setTabOrder(m_radioNewChmOpenNever, m_enableJava);
        QWidget::setTabOrder(m_enableJava, m_enablePlugins);
        QWidget::setTabOrder(m_enablePlugins, m_advViewSourceInternal);
        QWidget::setTabOrder(m_advViewSourceInternal, m_advViewSourceExternal);
        QWidget::setTabOrder(m_advViewSourceExternal, m_advExternalProgramName);
        QWidget::setTabOrder(m_advExternalProgramName, buttonBox);
        QWidget::setTabOrder(buttonBox, tabWidget);

        retranslateUi(DialogSetup);
        QObject::connect(m_advViewSourceExternal, SIGNAL(toggled(bool)), m_advExternalProgramName, SLOT(setEnabled(bool)));
        QObject::connect(buttonBox, SIGNAL(accepted()), DialogSetup, SLOT(accept()));
        QObject::connect(buttonBox, SIGNAL(rejected()), DialogSetup, SLOT(reject()));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(DialogSetup);
    } // setupUi

    void retranslateUi(QDialog *DialogSetup)
    {
        DialogSetup->setWindowTitle(QApplication::translate("DialogSetup", "KchmViewer settings", Q_NULLPTR));
        buttonGroup1->setTitle(QApplication::translate("DialogSetup", "If started with no arguments", Q_NULLPTR));
        rbStartWithNothing->setText(QApplication::translate("DialogSetup", "Start with nothing loaded", Q_NULLPTR));
        m_radioOnBeginOpenDialog->setText(QApplication::translate("DialogSetup", "Pop up the \"open file\" dialog", Q_NULLPTR));
        m_radioOnBeginOpenLast->setText(QApplication::translate("DialogSetup", "Open the &last used CHM file, if exist", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_radioOnBeginOpenLast->setShortcut(QApplication::translate("DialogSetup", "Alt+L", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        buttonGroup2->setTitle(QApplication::translate("DialogSetup", "History", Q_NULLPTR));
        textLabel1->setText(QApplication::translate("DialogSetup", "Store history information for", Q_NULLPTR));
        m_historySize->setPrefix(QString());
        textLabel2->setText(QApplication::translate("DialogSetup", "latest files", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        m_rememberHistoryInfo->setToolTip(QApplication::translate("DialogSetup", "Remembers the information about the files, which were opened. Remembers last opened page, search history, font size, bookmarks and so on.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        m_rememberHistoryInfo->setText(QApplication::translate("DialogSetup", "R&emember extra information for history files", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_rememberHistoryInfo->setShortcut(QApplication::translate("DialogSetup", "Alt+E", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        groupBox1->setTitle(QApplication::translate("DialogSetup", "CHM security settings", Q_NULLPTR));
        buttonGroup4->setTitle(QApplication::translate("DialogSetup", "When external link clicked", Q_NULLPTR));
        m_radioExtLinkOpenAlways->setText(QApplication::translate("DialogSetup", "Alwa&ys open it in external browser", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_radioExtLinkOpenAlways->setShortcut(QApplication::translate("DialogSetup", "Alt+Y", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        m_radioExtLinkAsk->setText(QApplication::translate("DialogSetup", "Ask for confirmation", Q_NULLPTR));
        m_radioExtLinkOpenNever->setText(QApplication::translate("DialogSetup", "Do not open the link", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_radioExtLinkOpenNever->setShortcut(QString());
#endif // QT_NO_SHORTCUT
        buttonGroup5->setTitle(QApplication::translate("DialogSetup", "When link pointed to a new CHM file clicked", Q_NULLPTR));
        m_radioNewChmOpenAlways->setText(QApplication::translate("DialogSetup", "Always open a new CHM file", Q_NULLPTR));
        m_radioNewChmAsk->setText(QApplication::translate("DialogSetup", "Ask for confirmation", Q_NULLPTR));
        m_radioNewChmOpenNever->setText(QApplication::translate("DialogSetup", "Do not open a new CHM file", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(Widget8), QApplication::translate("DialogSetup", "General behavior", Q_NULLPTR));
        m_groupKDEsettings->setTitle(QApplication::translate("DialogSetup", "HTML browser settings", Q_NULLPTR));
        m_enableImages->setText(QApplication::translate("DialogSetup", "Load the &images", Q_NULLPTR));
        m_enablePlugins->setText(QApplication::translate("DialogSetup", "Enable browser &plugins (i.e. Flash)", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_enablePlugins->setShortcut(QApplication::translate("DialogSetup", "Alt+P", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        m_enableJava->setText(QApplication::translate("DialogSetup", "Enable &Java", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_enableJava->setShortcut(QApplication::translate("DialogSetup", "Alt+J", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        m_enableJS->setText(QApplication::translate("DialogSetup", "Enable Java&Script", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_enableJS->setShortcut(QApplication::translate("DialogSetup", "Alt+S", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        m_enableOfflineStorage->setText(QApplication::translate("DialogSetup", "Enable &offline storage (HTML5)", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_enableOfflineStorage->setShortcut(QApplication::translate("DialogSetup", "Alt+R", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        m_enableLocalStorage->setText(QApplication::translate("DialogSetup", "Enable &local storage (HTML5)", Q_NULLPTR));
        m_highlightSearchResults->setText(QApplication::translate("DialogSetup", "Highlight search results during in-page search", Q_NULLPTR));
        groupBox_3->setTitle(QApplication::translate("DialogSetup", "Table of Contents and other windows", Q_NULLPTR));
        m_openAllTOCEntries->setText(QApplication::translate("DialogSetup", "Open all Table of Contents entries automatically", Q_NULLPTR));
        boxUseSingleClick->setText(QApplication::translate("DialogSetup", "Always use a single click to open the elements instead of OS-specific activation", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(Widget9), QApplication::translate("DialogSetup", "Browser", Q_NULLPTR));
        buttonGroup7->setTitle(QApplication::translate("DialogSetup", "View HTML source command uses", Q_NULLPTR));
        m_advViewSourceInternal->setText(QApplication::translate("DialogSetup", "Built-in HTML source viewer", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_advViewSourceInternal->setShortcut(QString());
#endif // QT_NO_SHORTCUT
        m_advViewSourceExternal->setText(QApplication::translate("DialogSetup", "E&xternal program, specified below", Q_NULLPTR));
#ifndef QT_NO_SHORTCUT
        m_advViewSourceExternal->setShortcut(QApplication::translate("DialogSetup", "Alt+X", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        textLabel1_3->setText(QApplication::translate("DialogSetup", "External program:", Q_NULLPTR));
        btnBrowse->setText(QApplication::translate("DialogSetup", "&Browse", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("DialogSetup", "Other", Q_NULLPTR));
        boxLayoutDirectionRL->setText(QApplication::translate("DialogSetup", "Use right-to-left layout direction (Arabic and Hebrew layouts)", Q_NULLPTR));
        boxAutodetectEncoding->setText(QApplication::translate("DialogSetup", "Automatically detect encoding for KHTMLPart and WebKit browsers (not recommended)", Q_NULLPTR));
#ifndef QT_NO_WHATSTHIS
        cbCheckForUpdates->setWhatsThis(QApplication::translate("DialogSetup", "If this option is enabled, the application will check for updates (when new version of application is released). If a new version is available, the program will show a messagebox dialog informing you about new version. This check will only performed once in 24 hours. No user information is requested or transmitted from your computer during this check.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        cbCheckForUpdates->setText(QApplication::translate("DialogSetup", "Perform a check whether a new version is available (once a week)", Q_NULLPTR));
        groupBox_2->setTitle(QApplication::translate("DialogSetup", "Toolbars", Q_NULLPTR));
        rbToolbarSmall->setText(QApplication::translate("DialogSetup", "Small icons", Q_NULLPTR));
        rbToolbarLarge->setText(QApplication::translate("DialogSetup", "Large icons", Q_NULLPTR));
        rbToolbarLargeText->setText(QApplication::translate("DialogSetup", "Large icons and text", Q_NULLPTR));
        rbToolbarText->setText(QApplication::translate("DialogSetup", "Just text", Q_NULLPTR));
        tabWidget->setTabText(tabWidget->indexOf(TabPage), QApplication::translate("DialogSetup", "Advanced", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class DialogSetup: public Ui_DialogSetup {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOG_SETUP_H
