/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QAction *file_Print_action;
    QAction *file_exit_action;
    QAction *edit_Copy_action;
    QAction *edit_SelectAll_action;
    QAction *edit_FindAction;
    QAction *file_ExtractCHMAction;
    QAction *settings_SettingsAction;
    QAction *bookmark_AddAction;
    QAction *view_Increase_font_size_action;
    QAction *view_Decrease_font_size_action;
    QAction *view_View_HTML_source_action;
    QAction *view_Toggle_fullscreen_action;
    QAction *view_Show_navigator_window;
    QAction *view_Locate_in_contents_action;
    QAction *view_Set_encoding_action;
    QAction *file_Open_action;
    QAction *nav_action_Back;
    QAction *nav_actionForward;
    QAction *nav_actionHome;
    QAction *nav_actionPreviousPage;
    QAction *nav_actionNextPageToc;
    QAction *action_Close_window;
    QAction *actionAbout_kchmviewer;
    QAction *actionAbout_Qt;
    QAction *actionCheck_for_updates;
    QAction *actionEdit_toolbars;
    QWidget *widget;
    QMenuBar *menubar;
    QMenu *menu_Settings;
    QMenu *menu_Bookmarks;
    QMenu *menu_File;
    QMenu *menu_Edit;
    QMenu *menu_View;
    QMenu *menu_Windows;
    QMenu *menuHelp;
    QToolBar *mainToolbar;
    QToolBar *navToolbar;
    QToolBar *viewToolbar;
    QStatusBar *mainStatusBar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName(QStringLiteral("MainWindow"));
        MainWindow->resize(873, 591);
        file_Print_action = new QAction(MainWindow);
        file_Print_action->setObjectName(QStringLiteral("file_Print_action"));
        QIcon icon;
        icon.addFile(QStringLiteral(":/images/icon_print.png"), QSize(), QIcon::Normal, QIcon::Off);
        file_Print_action->setIcon(icon);
        file_exit_action = new QAction(MainWindow);
        file_exit_action->setObjectName(QStringLiteral("file_exit_action"));
        QIcon icon1;
        icon1.addFile(QStringLiteral(":/images/find_close.png"), QSize(), QIcon::Normal, QIcon::Off);
        file_exit_action->setIcon(icon1);
        edit_Copy_action = new QAction(MainWindow);
        edit_Copy_action->setObjectName(QStringLiteral("edit_Copy_action"));
        QIcon icon2;
        icon2.addFile(QStringLiteral(":/images/icon_copy.png"), QSize(), QIcon::Normal, QIcon::Off);
        edit_Copy_action->setIcon(icon2);
        edit_SelectAll_action = new QAction(MainWindow);
        edit_SelectAll_action->setObjectName(QStringLiteral("edit_SelectAll_action"));
        QIcon icon3;
        icon3.addFile(QStringLiteral("image8"), QSize(), QIcon::Normal, QIcon::Off);
        edit_SelectAll_action->setIcon(icon3);
        edit_FindAction = new QAction(MainWindow);
        edit_FindAction->setObjectName(QStringLiteral("edit_FindAction"));
        QIcon icon4;
        icon4.addFile(QStringLiteral(":/images/icon_find.png"), QSize(), QIcon::Normal, QIcon::Off);
        edit_FindAction->setIcon(icon4);
        file_ExtractCHMAction = new QAction(MainWindow);
        file_ExtractCHMAction->setObjectName(QStringLiteral("file_ExtractCHMAction"));
        QIcon icon5;
        icon5.addFile(QStringLiteral(":/images/dryicons_save.png"), QSize(), QIcon::Normal, QIcon::Off);
        file_ExtractCHMAction->setIcon(icon5);
        settings_SettingsAction = new QAction(MainWindow);
        settings_SettingsAction->setObjectName(QStringLiteral("settings_SettingsAction"));
        QIcon icon6;
        icon6.addFile(QStringLiteral(":/images/dryicon_process.png"), QSize(), QIcon::Normal, QIcon::Off);
        settings_SettingsAction->setIcon(icon6);
        bookmark_AddAction = new QAction(MainWindow);
        bookmark_AddAction->setObjectName(QStringLiteral("bookmark_AddAction"));
        QIcon icon7;
        icon7.addFile(QStringLiteral(":/images/icon_add_bookmark.png"), QSize(), QIcon::Normal, QIcon::Off);
        bookmark_AddAction->setIcon(icon7);
        view_Increase_font_size_action = new QAction(MainWindow);
        view_Increase_font_size_action->setObjectName(QStringLiteral("view_Increase_font_size_action"));
        QIcon icon8;
        icon8.addFile(QStringLiteral(":/images/icon_font_increase.png"), QSize(), QIcon::Normal, QIcon::Off);
        view_Increase_font_size_action->setIcon(icon8);
        view_Decrease_font_size_action = new QAction(MainWindow);
        view_Decrease_font_size_action->setObjectName(QStringLiteral("view_Decrease_font_size_action"));
        QIcon icon9;
        icon9.addFile(QStringLiteral(":/images/icon_font_decrease.png"), QSize(), QIcon::Normal, QIcon::Off);
        view_Decrease_font_size_action->setIcon(icon9);
        view_View_HTML_source_action = new QAction(MainWindow);
        view_View_HTML_source_action->setObjectName(QStringLiteral("view_View_HTML_source_action"));
        QIcon icon10;
        icon10.addFile(QStringLiteral(":/images/icon_view_source.png"), QSize(), QIcon::Normal, QIcon::Off);
        view_View_HTML_source_action->setIcon(icon10);
        view_Toggle_fullscreen_action = new QAction(MainWindow);
        view_Toggle_fullscreen_action->setObjectName(QStringLiteral("view_Toggle_fullscreen_action"));
        view_Toggle_fullscreen_action->setCheckable(true);
        QIcon icon11;
        icon11.addFile(QStringLiteral(":/images/dryicons_window.png"), QSize(), QIcon::Normal, QIcon::Off);
        view_Toggle_fullscreen_action->setIcon(icon11);
        view_Toggle_fullscreen_action->setAutoRepeat(false);
        view_Show_navigator_window = new QAction(MainWindow);
        view_Show_navigator_window->setObjectName(QStringLiteral("view_Show_navigator_window"));
        view_Show_navigator_window->setCheckable(true);
        view_Show_navigator_window->setChecked(true);
        QIcon icon12;
        icon12.addFile(QStringLiteral(":/images/icon_locate_in_content.png"), QSize(), QIcon::Normal, QIcon::Off);
        view_Show_navigator_window->setIcon(icon12);
        view_Show_navigator_window->setAutoRepeat(false);
        view_Locate_in_contents_action = new QAction(MainWindow);
        view_Locate_in_contents_action->setObjectName(QStringLiteral("view_Locate_in_contents_action"));
        view_Locate_in_contents_action->setIcon(icon12);
        view_Set_encoding_action = new QAction(MainWindow);
        view_Set_encoding_action->setObjectName(QStringLiteral("view_Set_encoding_action"));
        QIcon icon13;
        icon13.addFile(QStringLiteral(":/images/dryicons_replace.png"), QSize(), QIcon::Normal, QIcon::Off);
        view_Set_encoding_action->setIcon(icon13);
        file_Open_action = new QAction(MainWindow);
        file_Open_action->setObjectName(QStringLiteral("file_Open_action"));
        QIcon icon14;
        icon14.addFile(QStringLiteral(":/images/icon_open_file.png"), QSize(), QIcon::Normal, QIcon::Off);
        file_Open_action->setIcon(icon14);
        nav_action_Back = new QAction(MainWindow);
        nav_action_Back->setObjectName(QStringLiteral("nav_action_Back"));
        QIcon icon15;
        icon15.addFile(QStringLiteral(":/images/icon_back.png"), QSize(), QIcon::Normal, QIcon::Off);
        nav_action_Back->setIcon(icon15);
        nav_actionForward = new QAction(MainWindow);
        nav_actionForward->setObjectName(QStringLiteral("nav_actionForward"));
        QIcon icon16;
        icon16.addFile(QStringLiteral(":/images/icon_forward.png"), QSize(), QIcon::Normal, QIcon::Off);
        nav_actionForward->setIcon(icon16);
        nav_actionHome = new QAction(MainWindow);
        nav_actionHome->setObjectName(QStringLiteral("nav_actionHome"));
        QIcon icon17;
        icon17.addFile(QStringLiteral(":/images/icon_home.png"), QSize(), QIcon::Normal, QIcon::Off);
        nav_actionHome->setIcon(icon17);
        nav_actionPreviousPage = new QAction(MainWindow);
        nav_actionPreviousPage->setObjectName(QStringLiteral("nav_actionPreviousPage"));
        QIcon icon18;
        icon18.addFile(QStringLiteral(":/images/icon_prev_page.png"), QSize(), QIcon::Normal, QIcon::Off);
        nav_actionPreviousPage->setIcon(icon18);
        nav_actionNextPageToc = new QAction(MainWindow);
        nav_actionNextPageToc->setObjectName(QStringLiteral("nav_actionNextPageToc"));
        QIcon icon19;
        icon19.addFile(QStringLiteral(":/images/icon_next_page.png"), QSize(), QIcon::Normal, QIcon::Off);
        nav_actionNextPageToc->setIcon(icon19);
        action_Close_window = new QAction(MainWindow);
        action_Close_window->setObjectName(QStringLiteral("action_Close_window"));
        QIcon icon20;
        icon20.addFile(QStringLiteral(":/images/closetab.png"), QSize(), QIcon::Normal, QIcon::Off);
        action_Close_window->setIcon(icon20);
        actionAbout_kchmviewer = new QAction(MainWindow);
        actionAbout_kchmviewer->setObjectName(QStringLiteral("actionAbout_kchmviewer"));
        actionAbout_Qt = new QAction(MainWindow);
        actionAbout_Qt->setObjectName(QStringLiteral("actionAbout_Qt"));
        actionCheck_for_updates = new QAction(MainWindow);
        actionCheck_for_updates->setObjectName(QStringLiteral("actionCheck_for_updates"));
        QIcon icon21;
        icon21.addFile(QStringLiteral(":/images/find_wrap.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionCheck_for_updates->setIcon(icon21);
        actionEdit_toolbars = new QAction(MainWindow);
        actionEdit_toolbars->setObjectName(QStringLiteral("actionEdit_toolbars"));
        actionEdit_toolbars->setIcon(icon11);
        widget = new QWidget(MainWindow);
        widget->setObjectName(QStringLiteral("widget"));
        MainWindow->setCentralWidget(widget);
        menubar = new QMenuBar(MainWindow);
        menubar->setObjectName(QStringLiteral("menubar"));
        menubar->setGeometry(QRect(0, 0, 873, 25));
        menu_Settings = new QMenu(menubar);
        menu_Settings->setObjectName(QStringLiteral("menu_Settings"));
        menu_Bookmarks = new QMenu(menubar);
        menu_Bookmarks->setObjectName(QStringLiteral("menu_Bookmarks"));
        menu_File = new QMenu(menubar);
        menu_File->setObjectName(QStringLiteral("menu_File"));
        menu_Edit = new QMenu(menubar);
        menu_Edit->setObjectName(QStringLiteral("menu_Edit"));
        menu_View = new QMenu(menubar);
        menu_View->setObjectName(QStringLiteral("menu_View"));
        menu_Windows = new QMenu(menubar);
        menu_Windows->setObjectName(QStringLiteral("menu_Windows"));
        menuHelp = new QMenu(menubar);
        menuHelp->setObjectName(QStringLiteral("menuHelp"));
        MainWindow->setMenuBar(menubar);
        mainToolbar = new QToolBar(MainWindow);
        mainToolbar->setObjectName(QStringLiteral("mainToolbar"));
        mainToolbar->setOrientation(Qt::Horizontal);
        mainToolbar->setIconSize(QSize(32, 32));
        mainToolbar->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        MainWindow->addToolBar(Qt::TopToolBarArea, mainToolbar);
        navToolbar = new QToolBar(MainWindow);
        navToolbar->setObjectName(QStringLiteral("navToolbar"));
        navToolbar->setOrientation(Qt::Horizontal);
        navToolbar->setIconSize(QSize(32, 32));
        navToolbar->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        MainWindow->addToolBar(Qt::TopToolBarArea, navToolbar);
        viewToolbar = new QToolBar(MainWindow);
        viewToolbar->setObjectName(QStringLiteral("viewToolbar"));
        viewToolbar->setOrientation(Qt::Horizontal);
        viewToolbar->setIconSize(QSize(32, 32));
        viewToolbar->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
        MainWindow->addToolBar(Qt::TopToolBarArea, viewToolbar);
        mainStatusBar = new QStatusBar(MainWindow);
        mainStatusBar->setObjectName(QStringLiteral("mainStatusBar"));
        MainWindow->setStatusBar(mainStatusBar);

        menubar->addAction(menu_File->menuAction());
        menubar->addAction(menu_Edit->menuAction());
        menubar->addAction(menu_View->menuAction());
        menubar->addAction(menu_Bookmarks->menuAction());
        menubar->addAction(menu_Windows->menuAction());
        menubar->addAction(menu_Settings->menuAction());
        menubar->addAction(menuHelp->menuAction());
        menu_Settings->addAction(settings_SettingsAction);
        menu_Settings->addAction(actionEdit_toolbars);
        menu_Settings->addSeparator();
        menu_Settings->addAction(actionCheck_for_updates);
        menu_Bookmarks->addAction(bookmark_AddAction);
        menu_Bookmarks->addSeparator();
        menu_File->addAction(file_Open_action);
        menu_File->addAction(file_Print_action);
        menu_File->addSeparator();
        menu_File->addAction(file_ExtractCHMAction);
        menu_File->addSeparator();
        menu_File->addAction(file_exit_action);
        menu_Edit->addAction(edit_Copy_action);
        menu_Edit->addAction(edit_SelectAll_action);
        menu_Edit->addSeparator();
        menu_Edit->addAction(edit_FindAction);
        menu_View->addAction(view_Increase_font_size_action);
        menu_View->addAction(view_Decrease_font_size_action);
        menu_View->addAction(view_View_HTML_source_action);
        menu_View->addSeparator();
        menu_View->addAction(view_Toggle_fullscreen_action);
        menu_View->addAction(view_Show_navigator_window);
        menu_View->addAction(view_Locate_in_contents_action);
        menu_View->addSeparator();
        menu_View->addAction(view_Set_encoding_action);
        menu_Windows->addAction(action_Close_window);
        menu_Windows->addSeparator();
        menuHelp->addAction(actionAbout_kchmviewer);
        menuHelp->addAction(actionAbout_Qt);
        mainToolbar->addAction(file_Open_action);
        mainToolbar->addAction(file_Print_action);
        navToolbar->addAction(nav_actionHome);
        navToolbar->addAction(nav_action_Back);
        navToolbar->addAction(nav_actionForward);
        viewToolbar->addAction(view_Locate_in_contents_action);
        viewToolbar->addAction(view_Decrease_font_size_action);
        viewToolbar->addAction(view_Increase_font_size_action);
        viewToolbar->addAction(view_View_HTML_source_action);
        viewToolbar->addAction(bookmark_AddAction);
        viewToolbar->addAction(nav_actionPreviousPage);
        viewToolbar->addAction(nav_actionNextPageToc);

        retranslateUi(MainWindow);

        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QApplication::translate("MainWindow", "kchmviewer", Q_NULLPTR));
        file_Print_action->setText(QApplication::translate("MainWindow", "&Print...", Q_NULLPTR));
        file_Print_action->setIconText(QApplication::translate("MainWindow", "Print", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        file_Print_action->setToolTip(QApplication::translate("MainWindow", "Print current page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        file_Print_action->setWhatsThis(QApplication::translate("MainWindow", "Prints currently opened page.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        file_Print_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+P", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        file_exit_action->setText(QApplication::translate("MainWindow", "&Quit", Q_NULLPTR));
        file_exit_action->setIconText(QApplication::translate("MainWindow", "Exit", Q_NULLPTR));
#ifndef QT_NO_WHATSTHIS
        file_exit_action->setWhatsThis(QApplication::translate("MainWindow", "Exits the application", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        file_exit_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+Q", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        edit_Copy_action->setText(QApplication::translate("MainWindow", "C&opy", Q_NULLPTR));
        edit_Copy_action->setIconText(QApplication::translate("MainWindow", "Copy", Q_NULLPTR));
#ifndef QT_NO_WHATSTHIS
        edit_Copy_action->setWhatsThis(QApplication::translate("MainWindow", "Copies selected content to clipboard", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        edit_Copy_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+C", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        edit_SelectAll_action->setText(QApplication::translate("MainWindow", "&Select All", Q_NULLPTR));
        edit_SelectAll_action->setIconText(QApplication::translate("MainWindow", "Paste", Q_NULLPTR));
#ifndef QT_NO_WHATSTHIS
        edit_SelectAll_action->setWhatsThis(QApplication::translate("MainWindow", "Selects everything in the document", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        edit_SelectAll_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+V", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        edit_FindAction->setText(QApplication::translate("MainWindow", "&Find...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        edit_FindAction->setToolTip(QApplication::translate("MainWindow", "Find text in currently opened page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        edit_FindAction->setWhatsThis(QApplication::translate("MainWindow", "Enters the Find in page mode", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        edit_FindAction->setShortcut(QApplication::translate("MainWindow", "Ctrl+F", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        file_ExtractCHMAction->setText(QApplication::translate("MainWindow", "E&xtract CHM content...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        file_ExtractCHMAction->setToolTip(QApplication::translate("MainWindow", "Extract the CHM content to the directory", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        file_ExtractCHMAction->setWhatsThis(QApplication::translate("MainWindow", "Exctracts the CHM archive content to the specified directory. All the files are extracted.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        settings_SettingsAction->setText(QApplication::translate("MainWindow", "&Application settings...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        settings_SettingsAction->setToolTip(QApplication::translate("MainWindow", "Change the application settings", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        settings_SettingsAction->setWhatsThis(QApplication::translate("MainWindow", "Change the application settings", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        bookmark_AddAction->setText(QApplication::translate("MainWindow", "&Add bookmark", Q_NULLPTR));
        bookmark_AddAction->setIconText(QApplication::translate("MainWindow", "Bookmark", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        bookmark_AddAction->setToolTip(QApplication::translate("MainWindow", "Adds a bookmark for currently opened page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        bookmark_AddAction->setWhatsThis(QApplication::translate("MainWindow", "Adds a bookmark for currently opened page. Remembers the opened page, and scroll position. Bookmarks are accessible through Bookmarks menu or tab.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        bookmark_AddAction->setShortcut(QApplication::translate("MainWindow", "Ctrl+B", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        view_Increase_font_size_action->setText(QApplication::translate("MainWindow", "&Increase font size", Q_NULLPTR));
        view_Increase_font_size_action->setIconText(QApplication::translate("MainWindow", "Larger", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        view_Increase_font_size_action->setToolTip(QApplication::translate("MainWindow", "Increase the font size", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        view_Increase_font_size_action->setWhatsThis(QApplication::translate("MainWindow", "Increases the document font size. The new font size will be stored.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        view_Increase_font_size_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+=", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        view_Decrease_font_size_action->setText(QApplication::translate("MainWindow", "&Decrease font size", Q_NULLPTR));
        view_Decrease_font_size_action->setIconText(QApplication::translate("MainWindow", "Smaller", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        view_Decrease_font_size_action->setToolTip(QApplication::translate("MainWindow", "Decrease the font size", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        view_Decrease_font_size_action->setWhatsThis(QApplication::translate("MainWindow", "Decreases the document font size. The new font size will be stored.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        view_Decrease_font_size_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+-", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        view_View_HTML_source_action->setText(QApplication::translate("MainWindow", "See &HTML", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        view_View_HTML_source_action->setToolTip(QApplication::translate("MainWindow", "View HTML source of current page", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        view_View_HTML_source_action->setWhatsThis(QApplication::translate("MainWindow", "Shows the HTML source of currently opened page", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        view_View_HTML_source_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+U", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        view_Toggle_fullscreen_action->setText(QApplication::translate("MainWindow", "Enable &full screen mode", Q_NULLPTR));
#ifndef QT_NO_WHATSTHIS
        view_Toggle_fullscreen_action->setWhatsThis(QApplication::translate("MainWindow", "Enters or leaves the fullscreen mode", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        view_Toggle_fullscreen_action->setShortcut(QApplication::translate("MainWindow", "F11", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        view_Show_navigator_window->setText(QApplication::translate("MainWindow", "Show &navigator window", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        view_Show_navigator_window->setToolTip(QApplication::translate("MainWindow", "Show navigator dock window", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        view_Show_navigator_window->setWhatsThis(QApplication::translate("MainWindow", "Shows or hides the size window (with Content, Index, Search and Bookmark tabs)", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        view_Show_navigator_window->setShortcut(QApplication::translate("MainWindow", "F9", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        view_Locate_in_contents_action->setText(QApplication::translate("MainWindow", "&Locate", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        view_Locate_in_contents_action->setToolTip(QApplication::translate("MainWindow", "Locate the current page in contents window", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        view_Locate_in_contents_action->setWhatsThis(QApplication::translate("MainWindow", "If the current page is present in the Table of Contents, locate it there. ", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        view_Locate_in_contents_action->setShortcut(QApplication::translate("MainWindow", "Ctrl+L", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        view_Set_encoding_action->setText(QApplication::translate("MainWindow", "Set &encoding", Q_NULLPTR));
#ifndef QT_NO_WHATSTHIS
        view_Set_encoding_action->setWhatsThis(QApplication::translate("MainWindow", "Changes the current document encoding. ", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        file_Open_action->setText(QApplication::translate("MainWindow", "&Open...", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        file_Open_action->setToolTip(QApplication::translate("MainWindow", "Open a CHM file", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        file_Open_action->setWhatsThis(QApplication::translate("MainWindow", "Opens a new CHM file", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        nav_action_Back->setText(QApplication::translate("MainWindow", "Back", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nav_action_Back->setToolTip(QApplication::translate("MainWindow", "Navigate back", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        nav_action_Back->setWhatsThis(QApplication::translate("MainWindow", "Navigate back in navigation history", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        nav_actionForward->setText(QApplication::translate("MainWindow", "Forward", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nav_actionForward->setToolTip(QApplication::translate("MainWindow", "Navigate forward", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        nav_actionForward->setWhatsThis(QApplication::translate("MainWindow", "Navigate forward in navigation history", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        nav_actionHome->setText(QApplication::translate("MainWindow", "Home", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nav_actionHome->setToolTip(QApplication::translate("MainWindow", "Navigate home", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        nav_actionHome->setWhatsThis(QApplication::translate("MainWindow", "Navigate to the document Home page, as specified in the document.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        nav_actionPreviousPage->setText(QApplication::translate("MainWindow", "Previous", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nav_actionPreviousPage->setToolTip(QApplication::translate("MainWindow", "Go to the previous page in the Table of Contents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        nav_actionPreviousPage->setWhatsThis(QApplication::translate("MainWindow", "Go to the previous page in the <b>Table of Contents</b><br><br><i>Shortcut: Ctrl+Left Arrow</i>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        nav_actionNextPageToc->setText(QApplication::translate("MainWindow", "Next", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        nav_actionNextPageToc->setToolTip(QApplication::translate("MainWindow", "Go to the next page in the Table of Contents", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        nav_actionNextPageToc->setWhatsThis(QApplication::translate("MainWindow", "Go to the next page in the <b>Table of Contents</b><br><br><i>Shortcut: Ctrl+Right Arrow</i>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        action_Close_window->setText(QApplication::translate("MainWindow", "&Close window", Q_NULLPTR));
#ifndef QT_NO_TOOLTIP
        action_Close_window->setToolTip(QApplication::translate("MainWindow", "Close current window", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_WHATSTHIS
        action_Close_window->setWhatsThis(QApplication::translate("MainWindow", "Closes currently opened window", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
#ifndef QT_NO_SHORTCUT
        action_Close_window->setShortcut(QApplication::translate("MainWindow", "Ctrl+W", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        actionAbout_kchmviewer->setText(QApplication::translate("MainWindow", "About kchmviewer...", Q_NULLPTR));
        actionAbout_Qt->setText(QApplication::translate("MainWindow", "About Qt", Q_NULLPTR));
        actionCheck_for_updates->setText(QApplication::translate("MainWindow", "Check for updates", Q_NULLPTR));
        actionEdit_toolbars->setText(QApplication::translate("MainWindow", "Edit toolbars...", Q_NULLPTR));
        menu_Settings->setTitle(QApplication::translate("MainWindow", "&Settings", Q_NULLPTR));
        menu_Bookmarks->setTitle(QApplication::translate("MainWindow", "&Bookmarks", Q_NULLPTR));
        menu_File->setTitle(QApplication::translate("MainWindow", "&File", Q_NULLPTR));
        menu_Edit->setTitle(QApplication::translate("MainWindow", "&Edit", Q_NULLPTR));
        menu_View->setTitle(QApplication::translate("MainWindow", "&View", Q_NULLPTR));
        menu_Windows->setTitle(QApplication::translate("MainWindow", "&Windows", Q_NULLPTR));
        menuHelp->setTitle(QApplication::translate("MainWindow", "Help", Q_NULLPTR));
        mainToolbar->setWindowTitle(QApplication::translate("MainWindow", "General toolbar", Q_NULLPTR));
        navToolbar->setWindowTitle(QApplication::translate("MainWindow", "Navigation toolbar", Q_NULLPTR));
        viewToolbar->setWindowTitle(QApplication::translate("MainWindow", "View toolbar", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
