/****************************************************************************
** Meta object code from reading C++ file 'checknewversion.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kchmviewer-7.7/src/checknewversion.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'checknewversion.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CheckNewVersion_t {
    QByteArrayData data[9];
    char stringdata0[104];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CheckNewVersion_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CheckNewVersion_t qt_meta_stringdata_CheckNewVersion = {
    {
QT_MOC_LITERAL(0, 0, 15), // "CheckNewVersion"
QT_MOC_LITERAL(1, 16, 19), // "newVersionAvailable"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 17), // "NewVersionMetaMap"
QT_MOC_LITERAL(4, 55, 8), // "metadata"
QT_MOC_LITERAL(5, 64, 13), // "statusChanged"
QT_MOC_LITERAL(6, 78, 9), // "newstatus"
QT_MOC_LITERAL(7, 88, 5), // "error"
QT_MOC_LITERAL(8, 94, 9) // "errorcode"

    },
    "CheckNewVersion\0newVersionAvailable\0"
    "\0NewVersionMetaMap\0metadata\0statusChanged\0"
    "newstatus\0error\0errorcode"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CheckNewVersion[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       5,    1,   32,    2, 0x06 /* Public */,
       7,    1,   35,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    8,

       0        // eod
};

void CheckNewVersion::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CheckNewVersion *_t = static_cast<CheckNewVersion *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->newVersionAvailable((*reinterpret_cast< const NewVersionMetaMap(*)>(_a[1]))); break;
        case 1: _t->statusChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->error((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NewVersionMetaMap >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (CheckNewVersion::*_t)(const NewVersionMetaMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CheckNewVersion::newVersionAvailable)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CheckNewVersion::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CheckNewVersion::statusChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (CheckNewVersion::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CheckNewVersion::error)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject CheckNewVersion::staticMetaObject = {
    { &QThread::staticMetaObject, qt_meta_stringdata_CheckNewVersion.data,
      qt_meta_data_CheckNewVersion,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CheckNewVersion::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CheckNewVersion::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CheckNewVersion.stringdata0))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int CheckNewVersion::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void CheckNewVersion::newVersionAvailable(const NewVersionMetaMap & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void CheckNewVersion::statusChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void CheckNewVersion::error(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
